# LangChain ASIMOV Integration

[![License](https://img.shields.io/badge/license-Public%20Domain-blue.svg)](https://unlicense.org)
[![Compatibility](https://img.shields.io/pypi/pyversions/langchain-asimov.svg)](https://pypi.python.org/pypi/langchain-asimov)
[![Package](https://img.shields.io/pypi/v/langchain-asimov.svg)](https://pypi.python.org/pypi/langchain-asimov)
